==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/backend/mail/api/gwt/serder/ImportMailboxItemSetMailboxItemIdGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.backend.mail.api.gwt.serder;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class ImportMailboxItemSetMailboxItemIdGwtSerDer implements GwtSerDer<net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId> {

	public ImportMailboxItemSetMailboxItemIdGwtSerDer( ) {
	}

	@Override
	public net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId ret = new net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId();
		deserializeTo(ret, json);

		return ret;
	}

	public void deserializeTo(net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId ret, JSONObject json) {

		JSONValue idJSON = json.get("id");
		ret.id =  GwtSerDerUtils.LONG.deserialize(idJSON);
	}

	@Override
	public JSONValue serialize(net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId o, JSONObject ret) {

		ret.put("id",  GwtSerDerUtils.LONG.serialize( o.id ));
	}
}

==> net.bluemind.p2.platform-5.5.3112.zip: net/bluemind/backend/mail/api/gwt/serder/ImportMailboxItemSetMailboxItemIdGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.backend.mail.api.gwt.serder;

import java.util.Set;
import java.util.HashSet;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class ImportMailboxItemSetMailboxItemIdGwtSerDer implements GwtSerDer<net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId> {

	public ImportMailboxItemSetMailboxItemIdGwtSerDer( ) {
	}

	@Override
	public net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId ret = new net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId();
		deserializeTo(ret, json);
		return ret;
	}

	public void deserializeTo(net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId ret, JSONObject json) {
		JSONValue idJSON = json.get("id");
		ret.id =  GwtSerDerUtils.LONG.deserialize(idJSON);
	}

	public void deserializeTo(net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId ret, JSONObject json, Set<String> childPropertiesToIgnore) {
		if (!childPropertiesToIgnore.contains("id")) {
			JSONValue idJSON = json.get("id");
			ret.id =  GwtSerDerUtils.LONG.deserialize(idJSON);
		}
	}


	@Override
	public JSONValue serialize(net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId o, JSONObject ret) {

		ret.put("id",  GwtSerDerUtils.LONG.serialize( o.id ));
	}

	public void serializeTo(net.bluemind.backend.mail.api.ImportMailboxItemSet.MailboxItemId o, JSONObject ret, Set<String> childPropertiesToIgnore) {

		if (!childPropertiesToIgnore.contains("id")) {
			ret.put("id",  GwtSerDerUtils.LONG.serialize( o.id ));
		}
	}


	public Set<String> propertiesToIgnore() {
		return new HashSet<>();
	}
}
